#[repr(C)]pub struct InnerPiece {
pub header: PieceHeader,
pub record: Record,
}Expand description
A piece of archival history.
This version is allocated on the stack, for a heap-allocated piece that can be moved around
efficiently, see Piece.
Internally, a piece contains a record, supplementary record chunk root, and a proof proving this piece belongs to can be used to verify that a piece belongs to the actual archival history of the blockchain.
Fields
header: PieceHeaderPiece header
record: RecordRecord contained within a piece
Implementations
Sourceimpl InnerPiece
impl InnerPiece
Sourcepub fn is_valid(
&self,
super_segment_root: &SuperSegmentRoot,
num_segments: u32,
position: PiecePosition,
) -> bool
pub fn is_valid( &self, super_segment_root: &SuperSegmentRoot, num_segments: u32, position: PiecePosition, ) -> bool
Check whether the piece is valid against the matching super segment root
Sourcepub fn record_root(&self) -> RecordRoot
pub fn record_root(&self) -> RecordRoot
Root of the record contained within a piece.
It is re-derived on every call of this function.
Sourcepub fn slice_to_repr(value: &[Self]) -> &[[u8; 1049560]]
pub fn slice_to_repr(value: &[Self]) -> &[[u8; 1049560]]
Convenient conversion from slice of piece array to underlying representation for efficiency purposes.
Sourcepub fn slice_from_repr(value: &[[u8; 1049560]]) -> &[Self]
pub fn slice_from_repr(value: &[[u8; 1049560]]) -> &[Self]
Convenient conversion from slice of underlying representation to piece array for efficiency purposes.
Sourcepub fn slice_mut_to_repr(value: &mut [Self]) -> &mut [[u8; 1049560]]
pub fn slice_mut_to_repr(value: &mut [Self]) -> &mut [[u8; 1049560]]
Convenient conversion from mutable slice of piece array to underlying representation for efficiency purposes.
Sourcepub fn slice_mut_from_repr(value: &mut [[u8; 1049560]]) -> &mut [Self]
pub fn slice_mut_from_repr(value: &mut [[u8; 1049560]]) -> &mut [Self]
Convenient conversion from mutable slice of underlying representation to piece array for efficiency purposes.