pub struct Record(/* private fields */);Expand description
Record contained within a piece.
NOTE: This is a stack-allocated data structure and can cause stack overflow!
Implementations
Sourceimpl Record
impl Record
Sourcepub const NUM_CHUNKS: usize
pub const NUM_CHUNKS: usize
Number of chunks within one record.
Sourcepub const NUM_S_BUCKETS: usize
pub const NUM_S_BUCKETS: usize
Number of s-buckets contained within one sector record.
Essentially we chunk records and erasure code them.
Sourcepub const SIZE: usize
pub const SIZE: usize
Size of a segment record, it is guaranteed to be a multiple of RecordChunk::SIZE
Sourcepub fn new_zero_vec(length: usize) -> Vec<Self>
pub fn new_zero_vec(length: usize) -> Vec<Self>
Create vector filled with zeroed records without hitting stack overflow
Sourcepub fn slice_to_repr(value: &[Self]) -> &[[[u8; 32]; 32768]]
pub fn slice_to_repr(value: &[Self]) -> &[[[u8; 32]; 32768]]
Convenient conversion from slice of record to underlying representation for efficiency purposes.
Sourcepub fn slice_from_repr(value: &[[[u8; 32]; 32768]]) -> &[Self]
pub fn slice_from_repr(value: &[[[u8; 32]; 32768]]) -> &[Self]
Convenient conversion from slice of underlying representation to record for efficiency purposes.
Sourcepub fn slice_mut_to_repr(value: &mut [Self]) -> &mut [[[u8; 32]; 32768]]
pub fn slice_mut_to_repr(value: &mut [Self]) -> &mut [[[u8; 32]; 32768]]
Convenient conversion from mutable slice of record to underlying representation for efficiency purposes.
Sourcepub fn slice_mut_from_repr(value: &mut [[[u8; 32]; 32768]]) -> &mut [Self]
pub fn slice_mut_from_repr(value: &mut [[[u8; 32]; 32768]]) -> &mut [Self]
Convenient conversion from mutable slice of underlying representation to record for efficiency purposes.
Sourcepub fn source_chunks_root(&self) -> RecordChunksRoot
pub fn source_chunks_root(&self) -> RecordChunksRoot
Derive source chunks root on-demand