pub struct SegmentProof(/* private fields */);Expand description
Proof that the segment belongs to a super segment
Implementations
Sourceimpl SegmentProof
impl SegmentProof
Sourcepub fn as_uninit_repr(&mut self) -> &mut [MaybeUninit<[u8; 32]>; 20]
pub fn as_uninit_repr(&mut self) -> &mut [MaybeUninit<[u8; 32]>; 20]
Returns a mutable reference to an internal array as uninitialized memory.
This is a convenience method for proof generation.